Django cradmin
==============
Django custom role based admin UI.

Django cradmin is in Alpha. The system is fairly stable, but:

- We do not have getting started guides.
- We not made browsable HTML api docs.
- We should have better tests before release. Some parts have been prototyped a lot while we tested out different concepts, and they need a complexity review and better tests.
- We have not made theming easy enough to customize, so custom themes are very likely to break.

.. image:: https://travis-ci.org/appressoas/django_cradmin.svg?branch=master
    :target: https://travis-ci.org/appressoas/django_cradmin


License
=======
3-clause BSD license. See the LICENSE file in the same directory as this readme file.
